@@ -1,7 +1,8 @@
 package Role::SQLite;
 
 use Class::Load qw(try_load_class);
-use File::Temp;
+use File::Spec;
+use File::Temp qw(tempfile);;
 
 use Test::Roo::Role;
 with 'Role::Database';
@@ -10,18 +11,26 @@ sub BUILD {
     try_load_class("DBD::SQLite") or plan skip_all => "DBD::SQLite required";
 }
 
-my $fh = File::Temp->new( TEMPLATE => 'upgrade_test_XXXXX', EXLOCK => 0 );
-my $dbfile = $fh->filename;
+my ( $fh, $dbfile ) = tempfile(
+    TEMPLATE => 'upgrade_test_XXXXX',
+    EXLOCK   => 0,
+    TMPDIR   => File::Spec->tmpdir
+);
 
+before clear_database => sub {
+    unlink($dbfile)
+      # can't unlink under Windows so on failure grab new tmpfile
+      # all our tempfiles will disappear when test exits
+      or ( $fh, $dbfile ) = tempfile(
+        TEMPLATE => 'upgrade_test_XXXXX',
+        EXLOCK   => 0,
+        TMPDIR   => File::Spec->tmpdir
+      );
+};
 after teardown => sub {
     shift->clear_database;
 };
 
-sub clear_database {
-    close($fh);
-    unlink($dbfile) or diag "Could not unlink $dbfile: $!";
-}
-
 sub _build_database {
 
     # does nothing atm for SQLite
@@ -35,7 +44,9 @@ sub _build_dbd_version {
 sub connect_info {
     my $self = shift;
 
-    return ( "dbi:SQLite:dbname=$dbfile", undef, undef,
+    return (
+        "dbi:SQLite:dbname=$dbfile",
+        undef, undef,
         {
             sqlite_unicode  => 1,
             on_connect_call => 'use_foreign_keys',
