@@ -19,24 +19,14 @@ __PACKAGE__->add_columns(
     },
     "width" => {
         data_type   => "integer",
-        is_nullable => 1,
-        versioned   => { since => '0.002', renamed_from => 'height' }
-    },
-    "bars_id" => {
-        data_type      => 'integer',
-        is_foreign_key => 1,
-        is_nullable    => 0,
-        versioned      => { since => '0.002' }
+        is_nullable => 0,
+        default_value => 1,
+        versioned   => { since => '0.002', renamed_from => 'height' },
     },
 );
 
 __PACKAGE__->set_primary_key('foos_id');
 
-__PACKAGE__->belongs_to(
-    'bar', 'TestVersion::Schema::Result::Bar',
-    'bars_id', { versioned => { since => '0.002' } },
-);
-
 __PACKAGE__->resultset_attributes( { versioned => { until => '0.003' } } );
 
 1;
