@@ -6,11 +6,13 @@ use warnings;
 __PACKAGE__->table('trees');
 
 __PACKAGE__->add_columns(
-    "trees_id" => { data_type => 'integer', is_auto_increment => 1,
-        versioned => { renamed_from => 'foos_id' }
+    "trees_id" => {
+        data_type         => 'integer',
+        is_auto_increment => 1,
+        versioned         => { renamed_from => 'foos_id' }
     },
-    "age"      => { data_type => "integer", is_nullable       => 1 },
-    "width"    => { data_type => "integer", is_nullable       => 0, default_value => 1 },
+    "age"   => { data_type => "integer", is_nullable => 1 },
+    "width" => { data_type => "integer", is_nullable => 0, default_value => 1 },
     "bars_id" =>
       { data_type => 'integer', is_foreign_key => 1, is_nullable => 1 },
 );
